@@ -26,9 +26,7 @@ use stdClass;
 #[UsesClass(BackupStaticProperties::class)]
 #[UsesClass(Before::class)]
 #[UsesClass(BeforeClass::class)]
-#[UsesClass(Covers::class)]
 #[UsesClass(CoversClass::class)]
-#[UsesClass(CoversDefaultClass::class)]
 #[UsesClass(CoversFunction::class)]
 #[UsesClass(CoversMethod::class)]
 #[UsesClass(CoversNothing::class)]
@@ -50,6 +48,7 @@ use stdClass;
 #[UsesClass(RequiresPhpExtension::class)]
 #[UsesClass(RequiresPhpunit::class)]
 #[UsesClass(RequiresPhpunitExtension::class)]
+#[UsesClass(RequiresEnvironmentVariable::class)]
 #[UsesClass(RequiresSetting::class)]
 #[UsesClass(RunClassInSeparateProcess::class)]
 #[UsesClass(RunInSeparateProcess::class)]
@@ -57,9 +56,7 @@ use stdClass;
 #[UsesClass(Test::class)]
 #[UsesClass(TestDox::class)]
 #[UsesClass(TestWith::class)]
-#[UsesClass(Uses::class)]
 #[UsesClass(UsesClass::class)]
-#[UsesClass(UsesDefaultClass::class)]
 #[UsesClass(UsesFunction::class)]
 #[Small]
 #[Group('metadata')]
@@ -119,8 +116,8 @@ final class MetadataCollectionTest extends TestCase
     {
         $collection = MetadataCollection::fromArray(
             [
-                Metadata::coversOnClass(''),
-                Metadata::coversOnMethod(''),
+                Metadata::coversClass(''),
+                Metadata::ignoreDeprecationsOnMethod(),
             ],
         );
 
@@ -181,12 +178,12 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isBefore());
     }
 
-    public function test_Can_be_filtered_for_Covers(): void
+    public function test_Can_be_filtered_for_CoversNamespace(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isCovers();
+        $collection = $this->collectionWithOneOfEach()->isCoversNamespace();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isCovers());
+        $this->assertTrue($collection->asArray()[0]->isCoversNamespace());
     }
 
     public function test_Can_be_filtered_for_CoversClass(): void
@@ -197,12 +194,20 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isCoversClass());
     }
 
-    public function test_Can_be_filtered_for_CoversDefaultClass(): void
+    public function test_Can_be_filtered_for_CoversClassesThatExtendClass(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isCoversDefaultClass();
+        $collection = $this->collectionWithOneOfEach()->isCoversClassesThatExtendClass();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isCoversDefaultClass());
+        $this->assertTrue($collection->asArray()[0]->isCoversClassesThatExtendClass());
+    }
+
+    public function test_Can_be_filtered_for_CoversClassesThatImplementInterface(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isCoversClassesThatImplementInterface();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isCoversClassesThatImplementInterface());
     }
 
     public function test_Can_be_filtered_for_CoversTrait(): void
@@ -414,6 +419,22 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isRequiresPhpunitExtension());
     }
 
+    public function test_Can_be_filtered_for_RequiresEnvironmentVariable(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isRequiresEnvironmentVariable();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isRequiresEnvironmentVariable());
+    }
+
+    public function test_Can_be_filtered_for_WithEnvironmentVariable(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isWithEnvironmentVariable();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isWithEnvironmentVariable());
+    }
+
     public function test_Can_be_filtered_for_RequiresSetting(): void
     {
         $collection = $this->collectionWithOneOfEach()->isRequiresSetting();
@@ -470,12 +491,12 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isTestWith());
     }
 
-    public function test_Can_be_filtered_for_Uses(): void
+    public function test_Can_be_filtered_for_UsesNamespace(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isUses();
+        $collection = $this->collectionWithOneOfEach()->isUsesNamespace();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isUses());
+        $this->assertTrue($collection->asArray()[0]->isUsesNamespace());
     }
 
     public function test_Can_be_filtered_for_UsesClass(): void
@@ -486,12 +507,20 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isUsesClass());
     }
 
-    public function test_Can_be_filtered_for_UsesDefaultClass(): void
+    public function test_Can_be_filtered_for_UsesClassesThatExtendClass(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isUsesDefaultClass();
+        $collection = $this->collectionWithOneOfEach()->isUsesClassesThatExtendClass();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isUsesDefaultClass());
+        $this->assertTrue($collection->asArray()[0]->isUsesClassesThatExtendClass());
+    }
+
+    public function test_Can_be_filtered_for_UsesClassesThatImplementInterface(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isUsesClassesThatImplementInterface();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isUsesClassesThatImplementInterface());
     }
 
     public function test_Can_be_filtered_for_UsesTrait(): void
@@ -536,9 +565,10 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::backupStaticPropertiesOnClass(true),
                 Metadata::beforeClass(0),
                 Metadata::before(0),
-                Metadata::coversOnClass(''),
+                Metadata::coversNamespace(''),
                 Metadata::coversClass(''),
-                Metadata::coversDefaultClass(''),
+                Metadata::coversClassesThatExtendClass(''),
+                Metadata::coversClassesThatImplementInterface(''),
                 Metadata::coversTrait(''),
                 Metadata::coversFunction(''),
                 Metadata::coversMethod('', ''),
@@ -574,6 +604,7 @@ final class MetadataCollectionTest extends TestCase
                     ),
                 ),
                 Metadata::requiresPhpunitExtensionOnClass(stdClass::class),
+                Metadata::requiresEnvironmentVariableOnClass('foo', 'bar'),
                 Metadata::requiresSettingOnClass('foo', 'bar'),
                 Metadata::runClassInSeparateProcess(),
                 Metadata::runInSeparateProcess(),
@@ -581,12 +612,14 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::testDoxOnClass(''),
                 Metadata::test(),
                 Metadata::testWith([]),
-                Metadata::usesOnClass(''),
+                Metadata::usesNamespace(''),
                 Metadata::usesClass(''),
-                Metadata::usesDefaultClass(''),
+                Metadata::usesClassesThatExtendClass(''),
+                Metadata::usesClassesThatImplementInterface(''),
                 Metadata::usesTrait(''),
                 Metadata::usesFunction(''),
                 Metadata::usesMethod('', ''),
+                Metadata::withEnvironmentVariableOnClass('foo', 'bar'),
                 Metadata::withoutErrorHandler(),
             ],
         );
