@@ -298,6 +298,26 @@ final class BuilderTest extends TestCase
         $configuration->coverageHtml();
     }
 
+    #[TestDox('--coverage-openclover file')]
+    public function testCoverageOpenClover(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--coverage-openclover', 'file']);
+
+        $this->assertTrue($configuration->hasCoverageOpenClover());
+        $this->assertSame('file', $configuration->coverageOpenClover());
+    }
+
+    public function testCoverageOpenCloverMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasCoverageOpenClover());
+
+        $this->expectException(Exception::class);
+
+        $configuration->coverageOpenClover();
+    }
+
     #[TestDox('--coverage-php file')]
     public function testCoveragePhp(): void
     {
@@ -938,6 +958,26 @@ final class BuilderTest extends TestCase
         $configuration->junitLogfile();
     }
 
+    #[TestDox('--log-otr file')]
+    public function testLogOtr(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--log-otr', 'file']);
+
+        $this->assertTrue($configuration->hasOtrLogfile());
+        $this->assertSame('file', $configuration->otrLogfile());
+    }
+
+    public function testLogOtrMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasOtrLogfile());
+
+        $this->expectException(Exception::class);
+
+        $configuration->otrLogfile();
+    }
+
     #[TestDox('--log-teamcity file')]
     public function testLogTeamcity(): void
     {
@@ -1303,6 +1343,46 @@ final class BuilderTest extends TestCase
         $configuration->failOnPhpunitDeprecation();
     }
 
+    #[TestDox('--fail-on-phpunit-notice')]
+    public function testFailOnPhpunitNotice(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--fail-on-phpunit-notice']);
+
+        $this->assertTrue($configuration->hasFailOnPhpunitNotice());
+        $this->assertTrue($configuration->failOnPhpunitNotice());
+    }
+
+    public function testFailOnPhpunitNoticeMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasFailOnPhpunitNotice());
+
+        $this->expectException(Exception::class);
+
+        $configuration->failOnPhpunitNotice();
+    }
+
+    #[TestDox('--fail-on-phpunit-warning')]
+    public function testFailOnPhpunitWarning(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--fail-on-phpunit-warning']);
+
+        $this->assertTrue($configuration->hasFailOnPhpunitWarning());
+        $this->assertTrue($configuration->failOnPhpunitWarning());
+    }
+
+    public function testFailOnPhpunitWarningMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasFailOnPhpunitWarning());
+
+        $this->expectException(Exception::class);
+
+        $configuration->failOnPhpunitWarning();
+    }
+
     #[TestDox('--fail-on-empty-test-suite')]
     public function testFailOnEmptyTestSuite(): void
     {
@@ -1423,6 +1503,186 @@ final class BuilderTest extends TestCase
         $configuration->failOnWarning();
     }
 
+    #[TestDox('--do-not-fail-on-deprecation')]
+    public function testDoNotFailOnDeprecation(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-deprecation']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnDeprecation());
+        $this->assertTrue($configuration->doNotFailOnDeprecation());
+    }
+
+    public function testDoNotFailOnDeprecationMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnDeprecation());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnDeprecation();
+    }
+
+    #[TestDox('--do-not-fail-on-phpunit-deprecation')]
+    public function testDoNotFailOnPhpunitDeprecation(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-phpunit-deprecation']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnPhpunitDeprecation());
+        $this->assertTrue($configuration->doNotFailOnPhpunitDeprecation());
+    }
+
+    public function testDoNotFailOnPhpunitDeprecationMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnPhpunitDeprecation());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnPhpunitDeprecation();
+    }
+
+    #[TestDox('--do-not-fail-on-phpunit-notice')]
+    public function testDoNotFailOnPhpunitNotice(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-phpunit-notice']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnPhpunitNotice());
+        $this->assertTrue($configuration->doNotFailOnPhpunitNotice());
+    }
+
+    public function testDoNotFailOnPhpunitNoticeMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnPhpunitNotice());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnPhpunitNotice();
+    }
+
+    #[TestDox('--do-not-fail-on-empty-test-suite')]
+    public function testDoNotFailOnEmptyTestSuite(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-empty-test-suite']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnEmptyTestSuite());
+        $this->assertTrue($configuration->doNotFailOnEmptyTestSuite());
+    }
+
+    public function testDoNotFailOnEmptyTestSuiteMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnEmptyTestSuite());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnEmptyTestSuite();
+    }
+
+    #[TestDox('--do-not-fail-on-incomplete')]
+    public function testDoNotFailOnIncomplete(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-incomplete']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnIncomplete());
+        $this->assertTrue($configuration->doNotFailOnIncomplete());
+    }
+
+    public function testDoNotFailOnIncompleteMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnIncomplete());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnIncomplete();
+    }
+
+    #[TestDox('--do-not-fail-on-notice')]
+    public function testDoNotFailOnNotice(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-notice']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnNotice());
+        $this->assertTrue($configuration->doNotFailOnNotice());
+    }
+
+    public function testDoNotFailOnNoticeMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnNotice());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnNotice();
+    }
+
+    #[TestDox('--do-not-fail-on-risky')]
+    public function testDoNotFailOnRisky(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-risky']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnRisky());
+        $this->assertTrue($configuration->doNotFailOnRisky());
+    }
+
+    public function testDoNotFailOnRiskyMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnRisky());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnRisky();
+    }
+
+    #[TestDox('--do-not-fail-on-skipped')]
+    public function testDoNotFailOnSkipped(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-skipped']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnSkipped());
+        $this->assertTrue($configuration->doNotFailOnSkipped());
+    }
+
+    public function testDoNotFailOnSkippedMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnSkipped());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnSkipped();
+    }
+
+    #[TestDox('--do-not-fail-on-warning')]
+    public function testDoNotFailOnWarning(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--do-not-fail-on-warning']);
+
+        $this->assertTrue($configuration->hasDoNotFailOnWarning());
+        $this->assertTrue($configuration->doNotFailOnWarning());
+    }
+
+    public function testDoNotFailOnWarningMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDoNotFailOnWarning());
+
+        $this->expectException(Exception::class);
+
+        $configuration->doNotFailOnWarning();
+    }
+
     #[TestDox('--stop-on-defect')]
     public function testStopOnDefect(): void
     {
@@ -1914,16 +2174,16 @@ final class BuilderTest extends TestCase
         $this->assertTrue($configuration->version());
     }
 
-    #[TestDox('--dont-report-useless-tests')]
-    public function testDontReportUselessTests(): void
+    #[TestDox('--do-not-report-useless-tests')]
+    public function testDoNotReportUselessTests(): void
     {
-        $configuration = (new Builder)->fromParameters(['--dont-report-useless-tests']);
+        $configuration = (new Builder)->fromParameters(['--do-not-report-useless-tests']);
 
         $this->assertTrue($configuration->hasReportUselessTests());
         $this->assertFalse($configuration->reportUselessTests());
     }
 
-    public function testDontReportUselessTestsMayNotBeConfigured(): void
+    public function testDoNotReportUselessTestsMayNotBeConfigured(): void
     {
         $configuration = (new Builder)->fromParameters([]);
 
@@ -2114,6 +2374,26 @@ final class BuilderTest extends TestCase
         $configuration->displayDetailsOnPhpunitDeprecations();
     }
 
+    #[TestDox('--display-phpunit-notices')]
+    public function testDisplayPhpunitNotices(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--display-phpunit-notices']);
+
+        $this->assertTrue($configuration->hasDisplayDetailsOnPhpunitNotices());
+        $this->assertTrue($configuration->displayDetailsOnPhpunitNotices());
+    }
+
+    public function testDisplayPhpunitNoticesMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDisplayDetailsOnPhpunitNotices());
+
+        $this->expectException(Exception::class);
+
+        $configuration->displayDetailsOnPhpunitNotices();
+    }
+
     #[TestDox('--display-errors')]
     public function testDisplayErrors(): void
     {
@@ -2335,6 +2615,14 @@ final class BuilderTest extends TestCase
         $this->assertTrue($configuration->debug());
     }
 
+    #[TestDox('--with-telemetry')]
+    public function testWithTelemetry(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--with-telemetry']);
+
+        $this->assertTrue($configuration->withTelemetry());
+    }
+
     #[TestDox('--extension')]
     public function testExtension(): void
     {
