@@ -29,10 +29,12 @@ use PHPUnit\Event\Test\Failed;
 use PHPUnit\Event\Test\MarkedIncomplete;
 use PHPUnit\Event\Test\PhpunitDeprecationTriggered;
 use PHPUnit\Event\Test\PhpunitErrorTriggered;
+use PHPUnit\Event\Test\PhpunitNoticeTriggered;
 use PHPUnit\Event\Test\PhpunitWarningTriggered;
 use PHPUnit\Event\Test\Skipped as TestSkipped;
 use PHPUnit\Event\TestData\TestDataCollection;
 use PHPUnit\Event\TestRunner\DeprecationTriggered as TestRunnerDeprecationTriggered;
+use PHPUnit\Event\TestRunner\NoticeTriggered as TestRunnerNoticeTriggered;
 use PHPUnit\Event\TestRunner\WarningTriggered as TestRunnerWarningTriggered;
 use PHPUnit\Event\TestSuite\Skipped as TestSuiteSkipped;
 use PHPUnit\Framework\Attributes\CoversClass;
@@ -345,6 +347,33 @@ final class ResultPrinterTest extends TestCase
                 ),
             ],
 
+            'successful test and PHPUnit test runner notice' => [
+                __DIR__ . '/expectations/successful_test_and_phpunit_test_runner_notice.txt',
+                self::createTestResult(
+                    testRunnerTriggeredNoticeEvents: [
+                        new TestRunnerNoticeTriggered(
+                            self::telemetryInfo(),
+                            'message',
+                        ),
+                    ],
+                ),
+            ],
+
+            'successful test that triggers PHPUnit notice' => [
+                __DIR__ . '/expectations/successful_test_with_phpunit_notice.txt',
+                self::createTestResult(
+                    testTriggeredPhpunitNoticeEvents: [
+                        'Foo::testBar' => [
+                            new PhpunitNoticeTriggered(
+                                self::telemetryInfo(),
+                                self::testMethod(),
+                                'message',
+                            ),
+                        ],
+                    ],
+                ),
+            ],
+
             'successful test that triggers PHPUnit warning' => [
                 __DIR__ . '/expectations/successful_test_with_phpunit_warning.txt',
                 self::createTestResult(
@@ -395,6 +424,7 @@ final class ResultPrinterTest extends TestCase
             true,
             true,
             true,
+            true,
             false,
         );
 
@@ -452,11 +482,13 @@ final class ResultPrinterTest extends TestCase
      * @param list<Issue>                                     $warnings
      * @param list<Issue>                                     $phpWarnings
      * @param array<string,list<PhpunitErrorTriggered>>       $testTriggeredPhpunitErrorEvents
+     * @param array<string,list<PhpunitNoticeTriggered>>      $testTriggeredPhpunitNoticeEvents
      * @param array<string,list<PhpunitWarningTriggered>>     $testTriggeredPhpunitWarningEvents
      * @param list<TestRunnerDeprecationTriggered>            $testRunnerTriggeredDeprecationEvents
+     * @param list<TestRunnerNoticeTriggered>                 $testRunnerTriggeredNoticeEvents
      * @param list<TestRunnerWarningTriggered>                $testRunnerTriggeredWarningEvents
      */
-    private static function createTestResult(int $numberOfTests = 1, int $numberOfTestsRun = 1, int $numberOfAssertions = 1, array $testErroredEvents = [], array $testFailedEvents = [], array $testConsideredRiskyEvents = [], array $testSuiteSkippedEvents = [], array $testSkippedEvents = [], array $testMarkedIncompleteEvents = [], array $deprecations = [], array $phpDeprecations = [], array $testTriggeredPhpunitDeprecationEvents = [], array $errors = [], array $notices = [], array $phpNotices = [], array $warnings = [], array $phpWarnings = [], array $testTriggeredPhpunitErrorEvents = [], array $testTriggeredPhpunitWarningEvents = [], array $testRunnerTriggeredDeprecationEvents = [], array $testRunnerTriggeredWarningEvents = [], int $numberOfIssuesIgnoredByBaseline = 0): TestResult
+    private static function createTestResult(int $numberOfTests = 1, int $numberOfTestsRun = 1, int $numberOfAssertions = 1, array $testErroredEvents = [], array $testFailedEvents = [], array $testConsideredRiskyEvents = [], array $testSuiteSkippedEvents = [], array $testSkippedEvents = [], array $testMarkedIncompleteEvents = [], array $deprecations = [], array $phpDeprecations = [], array $testTriggeredPhpunitDeprecationEvents = [], array $errors = [], array $notices = [], array $phpNotices = [], array $warnings = [], array $phpWarnings = [], array $testTriggeredPhpunitErrorEvents = [], array $testTriggeredPhpunitNoticeEvents = [], array $testTriggeredPhpunitWarningEvents = [], array $testRunnerTriggeredDeprecationEvents = [], array $testRunnerTriggeredNoticeEvents = [], array $testRunnerTriggeredWarningEvents = [], int $numberOfIssuesIgnoredByBaseline = 0): TestResult
     {
         return new TestResult(
             $numberOfTests,
@@ -470,8 +502,10 @@ final class ResultPrinterTest extends TestCase
             $testMarkedIncompleteEvents,
             $testTriggeredPhpunitDeprecationEvents,
             $testTriggeredPhpunitErrorEvents,
+            $testTriggeredPhpunitNoticeEvents,
             $testTriggeredPhpunitWarningEvents,
             $testRunnerTriggeredDeprecationEvents,
+            $testRunnerTriggeredNoticeEvents,
             $testRunnerTriggeredWarningEvents,
             $errors,
             $deprecations,
